#!/usr/bin/env python

"""
ADC (voltage sampler with plotting capability) example layout
v2

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import serial
import easyterm_api
import configparser
config = configparser.ConfigParser(inline_comment_prefixes="#")
config.read('config.ini')

with serial.Serial(config['COM']['CFG_COM_PORT'], int(config['COM']['CFG_BAUD_RATE']), timeout=float(config['COM']['CFG_REPLY_TIMEOUT'])) as ser:    
    et = easyterm_api.EasyTermApi(ser)
    
    #Uncomment to reset
    #et.soft_reset()
    
    #Clear current screen page to make sure there is space for widgets
    et.clear_screen_page()
    
    #Header
    et.transceive('dg x=60 y=5 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    et.transceive('dt a=c x=160 y=10 t="ADC" f=18b;', echo=True)
    et.transceive('dg x=60 y=30 w=200 h=3 c=0,0,100 ga=h gd=s gi=5;', echo=True)
    
    #Simple conversion
    et.transceive('dt x=160 y=35 bw=300 t="Oneshot conversion" a=c ld=l;', echo=True)
    et.transceive('db x=54 y=51 c=0,0,100 w=106 h=35 t="Convert" a="ADC v=?";', echo=True)
    et.transceive('df x=161 y=51 gc=0,0,0 w=106 h=35 t="Voltage(mV)" ft=vt pm="ADC v=%d\\r\\n";', echo=True)
    
    #Conversions to buffer
    et.transceive('dt x=160 y=90 bw=300 t="Continuous conversion(to buffer)" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=106 c=0,0,100 w=78 h=35 t="Set rate(Hz)" a="ADC sr=%dHz";', echo=True)
    et.transceive('db x=82 y=106 c=0,0,100 w=78 h=35 t="Set count" a="ADC sc=%d";', echo=True)
    et.transceive('db x=161 y=106 c=0,0,100 w=157 h=35 t="Read buffer" a="ADC rb=?";', echo=True)
    
    #Start/stop oneshot conversions to buffer
    et.transceive('db x=3 y=142 c=0,0,100 w=157 h=35 t="Start oneshot" a="ADC os=1";', echo=True)
    et.transceive('db x=161 y=142 c=0,0,100 w=157 h=35 t="Stop oneshot" a="ADC os=0";', echo=True)
    
    #Start/stop continuous conversions to buffer
    et.transceive('db x=3 y=178 c=0,0,100 w=157 h=35 t="Start continuous" a="ADC cc=1";', echo=True)
    et.transceive('db x=161 y=178 c=0,0,100 w=157 h=35 t="Stop continuous" a="ADC cc=0";', echo=True)
    
    #Timer-triggered simple conversions
    et.transceive('dt x=160 y=215 bw=300 t="Timer triggered conversions with plotting" a=c ld=l;', echo=True)
    et.transceive('db x=3 y=231 c=0,0,100 w=157 h=35 t="Set period and start" a="TIM p=%d s=1 a=\\"ADC v=?\\"";', echo=True)
    et.transceive('db x=161 y=231 c=0,0,100 w=157 h=35 t="Stop" a="TIM s=0";', echo=True)
    et.transceive('dp x=9 m=a y=270 w=310 h=160 pm="ADC v=%d\\r\\n";', echo=True)
    
    #Read buffer command replies form
    et.transceive('df x=0 y=430 w=320 h=30 t="- Buffer -" pm="ADC rb=%s\\r\\n";', echo=True)
    
    #EasyTerm replies form
    et.transceive('dg x=10 y=463 w=300 h=1 c=50,50,50;', echo=True)
    et.transceive('df x=0 y=465 w=320 h=15 ft=vo pm="%s\\r\\n";', echo=True)
    
    #Uncomment to save layout in flash and recover after device startup
    #et.transceive('sl bid=0;', echo=True, custom_timeout=2)
    #et.transceive('sys coi="ll bid=0";', echo=True, custom_timeout=2)
    
