#!/usr/bin/env python

"""
Simple EasyTerm communication API
v1.0.0

Please adjust config.ini file. EasyTerm can be connected through USB or through USB-UART adapter
See manual (chapter "Master connection configurations") in case of problems
"""

import time

class EasyTermApi():
    def __init__(self, serial_instance, device_type="eterm35", receive_reply=True):
        if(device_type == "eterm35"):
            self.screen_width = 320
            self.screen_height = 480
        else:
            print("Unsupported device: " + device_type)
        
        self.serial_instance = serial_instance
        self.receive_reply = receive_reply
    
    def transceive(self, str_to_send, echo=False, receive_reply=None, custom_timeout=None):
        if echo == True:
            print("> " + str_to_send)
        str_bytes = str_to_send.encode('ascii')
        self.flush_received_data()
        self.serial_instance.write(str_bytes)
        
        if ((receive_reply == None and self.receive_reply == True) or receive_reply == True):
            if(custom_timeout != None):
                prev_timeout = self.serial_instance.timeout
                self.serial_instance.timeout = custom_timeout
                
            reply_lines = self.serial_instance.readlines()
            decoded_lines = [i.decode('ascii', errors='ignore') for i in reply_lines]

            if(custom_timeout != None):
                self.serial_instance.timeout = prev_timeout
            
            if(len(reply_lines) != 0):
                print(decoded_lines)
                return decoded_lines
    
    def flush_received_data(self):
        self.serial_instance.reset_input_buffer()
        self.serial_instance.read(self.serial_instance.in_waiting)
            
    def print_received_data(self):
        reply_lines = self.serial_instance.readlines()
        decoded_lines = [i.decode('ascii', errors='ignore') for i in reply_lines]
        if(decoded_lines != None):
            print(decoded_lines)
        else:
            print("pokus")
        
    def read_received_data(self):
        reply_lines = self.serial_instance.readlines()
        decoded_lines = [i.decode('ascii', errors='ignore') for i in reply_lines]
        return decoded_lines
        
    def clear_screen_pages(self):
        self.transceive("csp sp=all;")
        
    def clear_screen_page(self, screen_page_index=None):
        if(screen_page_index == None):
            self.transceive("csp;")
        else:
            self.transceive("csp sp=" + str(screen_page_index) + ";")
        
    def hard_reset(self):
        self.transceive("sys hardReset;")
        
        #System reset takes some time -> wait
        time.sleep(1)
        
        #Now it is possible to read device startup acknowledge
        self.print_received_data()
            
    def soft_reset(self):
        self.transceive("sys softReset;")
        
        #System reset takes some time -> wait
        time.sleep(1)
        